@@ -10,6 +10,10 @@ dSugg = {
     "cdlt": "cordialement",
     "construirent": "construire|construisirent|construisent|construiront",
     "càd": "c’est-à-dire",
+    "chai": "j’sais|je sais",
+    "chais": "j’sais|je sais",
+    "chui": "j’suis|je suis",
+    "chuis": "j’suis|je suis",
     "done": "donc|donne",
     "dc": "de|donc",
     "email": "courriel|e-mail|émail",
@@ -27,6 +31,8 @@ dSugg = {
     "pdq": "pendant que",
     "pdt": "pendant",
     "pdtq": "pendant que",
+    "pécunier": "pécuniaire",
+    "pécuniers": "pécuniaires",
     "pk": "pourquoi",
     "pkoi": "pourquoi",
     "pq": "pourquoi|PQ",
