@@ -57,6 +57,8 @@ class SuggResult:
         if sSugg not in self.aSugg:
             nDist = st.distanceDamerauLevenshtein(self.sSimplifiedWord, cp.simplifyWord(sSugg))
             if nDist <= self.nDistLimit:
+                if " " in sSugg:
+                    nDist += 1
                 if nDist not in self.dSugg:
                     self.dSugg[nDist] = []
                 self.dSugg[nDist].append(sSugg)
@@ -317,7 +319,7 @@ class IBDAWG:
 
     def _splitTrailingNumbers (self, oSuggResult, sWord):
         m = re.match(r"(\D+)([0-9]+)$", sWord)
-        if m:
+        if m and m.group(1)[-1:].isalpha():
             oSuggResult.addSugg(m.group(1) + " " + cp.numbersToExponent(m.group(2)))
 
     def _splitSuggest (self, oSuggResult, sWord):
