@@ -5,6 +5,8 @@ using regular expressions
 
 import re
 
+from unicodedata import normalize
+
 _PATTERNS = {
     "default":
         (
@@ -36,7 +38,7 @@ _PATTERNS = {
             r'(?P<HOUR>\d\d?[h:]\d\d(?:[m:]\d\ds?|)\b)',
             r'(?P<NUM>\d+(?:[.,]\d+|))',
             r'(?P<SIGN>[&%‰€$+±=*/<>⩾⩽#|×¥£¢§¬÷@-])',
-            r"(?P<WORD>\w+(?:[’'`-]\w+)*)"
+            r"(?P<WORD>[\w\u0300-\u036f]+(?:[’'`-][\w\u0300-\u036f]+)*)"
         )
 }
 
@@ -56,7 +58,7 @@ class Tokenizer:
         if bStartEndToken:
             yield { "i": 0, "sType": "INFO", "sValue": "<start>", "nStart": 0, "nEnd": 0, "lMorph": ["<start>"] }
         for i, m in enumerate(self.zToken.finditer(sText), 1):
-            yield { "i": i, "sType": m.lastgroup, "sValue": m.group(), "nStart": m.start(), "nEnd": m.end() }
+            yield { "i": i, "sType": m.lastgroup, "sValue": normalize("NFC", m.group()), "nStart": m.start(), "nEnd": m.end() }
         if bStartEndToken:
             iEnd = len(sText)
             yield { "i": i+1, "sType": "INFO", "sValue": "<end>", "nStart": iEnd, "nEnd": iEnd, "lMorph": ["<end>"] }
